Scenario: Gain access to a remote secret service that is placed in a docker network
===================================================================================

Requirements and assumptions:
- Given you have a remote SSH account and forwarding allowed on remote host
- The SSH server is in a docker container
